class UsersGetAllOrders(object):
    def __init__(self, key, user_id):
        self.key = key
        self.user_id = user_id

    # 业务密钥
    key = ""
    # 用户id
    user_id = ""
    # 产品类型
    product_type = ""
